pub fn text(
src_lines: &Vec<String>,
base_indent: usize,
section_level: &mut usize,
line_cursor: &mut LineCursor,
doctree: DocTree,
captures: &Captures<'_>,
pattern_name: &Pattern,
) -> TransitionResultExpand description
A function that handles the parsing of blocks that start with text. This includes paragraphs, but also underlined titles and definition lists. The latter are detected via lookahead.