pub enum IndentationMatch {
TooLittle,
JustRight,
TooMuch,
}Expand description
A enumeration of the different ways a node’s child indentation might interact with the indentation of the parent.
Variants
TooLittle
If a (sub)?body node has less indentation than its parent would require, it is interpreted as not belonging to the currently focused on node.
JustRight
This node belongs to the parent node.
TooMuch
This node is most likely a block quote.