pub enum IndentedBlockResult {
Ok {
lines: Vec<String>,
minimum_indent: usize,
offset: usize,
blank_finish: bool,
},
EmptyLinesErr,
UnfinishedErr {
lines: Vec<String>,
minimum_indent: usize,
offset: usize,
blank_finish: bool,
},
}Expand description
A enumeration of the different ways the function Parser::read_indented_block could succeed or fail.
Variants
Ok
The reading of the text block succeeded as intended
EmptyLinesErr
The given line vector was empty
UnfinishedErr